-
Notifications
You must be signed in to change notification settings - Fork 3
Expand file tree
/
Copy pathfiles.html
More file actions
208 lines (206 loc) · 24.2 KB
/
Copy pathfiles.html
File metadata and controls
208 lines (206 loc) · 24.2 KB
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
<!-- HTML header for doxygen 1.9.1-->
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<!-- Google tag (gtag.js) -->
<script async src="https://www.googletagmanager.com/gtag/js?id=G-SY496B9L99"></script>
<script>
window.dataLayer = window.dataLayer || [];
function gtag(){dataLayer.push(arguments);}
gtag('js', new Date());
gtag('config', 'G-SY496B9L99');
</script>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" content="Doxygen 1.16.1"/>
<meta name="viewport" content="width=device-width, initial-scale=1"/>
<title>MFC: File List</title>
<meta name="description" content="File List — MFC documentation. Open-source exascale multiphase flow solver." />
<meta name="keywords" content="exascale, fluid dynamics, cfd, computational fluid dynamics, compressible, hpc, bryngelson, colonius, subgrid, multiphase, frontier, summit, el capitan, aurora, amd gpu, gpu, nvidia"/>
<link href="tabs.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="jquery.js"></script>
<script type="text/javascript" src="dynsections.js"></script>
<link href="navtree.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="navtreedata.js"></script>
<script type="text/javascript" src="navtree.js"></script>
<script type="text/javascript" src="cookie.js"></script>
<link href="search/search.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="search/searchdata.js"></script>
<script type="text/javascript" src="search/search.js"></script>
<script type="text/x-mathjax-config">
MathJax.Hub.Config({
extensions: ["tex2jax.js", "TeX/AMSmath.js", "TeX/AMSsymbols.js"],
jax: ["input/TeX","output/HTML-CSS"],
});
// This file is set as MATHJAX_CODEFILE in the Doxyfile. It configures how
// MathJax renders expressions in Markdown so that it is consistent with GitHub.
MathJax.Hub.Config({
extensions: ["tex2jax.js"],
jax: ["input/TeX", "output/HTML-CSS"],
tex2jax: {
inlineMath: [ ['$', '$'], ["\\(","\\)"] ],
displayMath: [ ['$$','$$'], ["\\[","\\]"] ],
processEscapes: true,
ignoreClass: "line" // Ignore code blocks: https://web.archive.org/web/20120430100225/http://www.mathjax.org/docs/1.1/options/tex2jax.html
},
"HTML-CSS": {
fonts: ["TeX"]
}
});
</script>
<script type="text/javascript" async="async" src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js"></script>
<link href="doxygen.css" rel="stylesheet" type="text/css" />
<link rel="shortcut icon" href="icon.ico" type="image/x-icon" />
<link href="doxygen-awesome.css" rel="stylesheet" type="text/css"/>
<link href="doxygen-awesome-sidebar-only.css" rel="stylesheet" type="text/css"/>
<link href="custom.css" rel="stylesheet" type="text/css"/>
</head>
<body>
<div id="top"><!-- do not remove this div, it is closed by doxygen! -->
<div id="titlearea">
<table cellspacing="0" cellpadding="0">
<tbody>
<tr style="height: 56px;">
<td id="projectlogo"><img alt="Logo" src="icon.ico"/></td>
<td id="projectalign" style="padding-left: 0.5em;">
<div id="projectname">MFC
</div>
<div id="projectbrief">Exascale flow solver</div>
</td>
</tr>
</tbody>
</table>
</div>
<!-- Cross-navigation injected into sidebar via script below -->
<script>
document.addEventListener('DOMContentLoaded', function() {
var nav = document.createElement('div');
nav.id = 'mfc-nav';
var items = [
['../documentation/index.html', 'documentation', 'User Guide'],
['../api/index.html', 'api', 'API Documentation']
];
var path = window.location.pathname;
var apiPaths = ['/api/', '/pre_process/', '/simulation/', '/post_process/'];
for (var i = 0; i < items.length; i++) {
var a = document.createElement('a');
a.href = items[i][0];
a.textContent = items[i][2];
if (items[i][1] === 'api') {
for (var j = 0; j < apiPaths.length; j++) {
if (path.indexOf(apiPaths[j]) !== -1) { a.className = 'active'; break; }
}
} else {
if (path.indexOf('/' + items[i][1] + '/') !== -1) a.className = 'active';
}
nav.appendChild(a);
}
var sideNav = document.getElementById('side-nav');
if (sideNav) sideNav.insertBefore(nav, sideNav.firstChild);
});
</script>
<!-- end header part -->
<!-- Generated by Doxygen 1.16.1 -->
<script type="text/javascript">
var searchBox = new SearchBox("searchBox", "search/",'.html');
</script>
<script type="text/javascript">
$(function() { codefold.init(); });
</script>
<script type="text/javascript" src="menudata.js"></script>
<script type="text/javascript" src="menu.js"></script>
<script type="text/javascript">
$(function() {
initMenu('',true,false,'search.php','Search',true);
$(function() { init_search(); });
});
</script>
<div id="main-nav"></div>
</div><!-- top -->
<div id="side-nav" class="ui-resizable side-nav-resizable">
<div id="nav-tree">
<div id="nav-tree-contents">
<div id="nav-sync" class="sync"></div>
</div>
</div>
<div id="splitbar" style="-moz-user-select:none;"
class="ui-resizable-handle">
</div>
</div>
<script type="text/javascript">
$(function(){initNavTree('files.html','',''); });
</script>
<div id="container">
<div id="doc-content">
<!-- window showing the filter options -->
<div id="MSearchSelectWindow"
onmouseover="return searchBox.OnSearchSelectShow()"
onmouseout="return searchBox.OnSearchSelectHide()"
onkeydown="return searchBox.OnSearchSelectKey(event)">
</div>
<!-- iframe showing the search results (closed by default) -->
<div id="MSearchResultsWindow">
<div id="MSearchResults">
<div class="SRPage">
<div id="SRIndex">
<div id="SRResults"></div>
<div class="SRStatus" id="Loading">Loading...</div>
<div class="SRStatus" id="Searching">Searching...</div>
<div class="SRStatus" id="NoMatches">No Matches</div>
</div>
</div>
</div>
</div>
<div class="header">
<div class="headertitle"><div class="title">File List</div></div>
</div><!--header-->
<div class="contents">
<div class="textblock">Here is a list of all files with brief descriptions:</div><div class="directory">
<table class="directory">
<tr id="row_0_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__assign__variables_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__assign__variables_8fpp_8f90.html" target="_self">m_assign_variables.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__assign__variables.html" title="Assigns initial primitive variables to computational cells based on patch geometry.">m_assign_variables</a> </td></tr>
<tr id="row_1_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__boundary__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__boundary__common_8fpp_8f90.html" target="_self">m_boundary_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__boundary__common.html" title="Noncharacteristic and processor boundary condition application for ghost cells and buffer regions.">m_boundary_common</a> </td></tr>
<tr id="row_2_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__boundary__conditions_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__boundary__conditions_8fpp_8f90.html" target="_self">m_boundary_conditions.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__boundary__conditions.html" title="Applies spatially varying boundary condition patches along domain edges and faces.">m_boundary_conditions</a> </td></tr>
<tr id="row_3_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__boundary__io_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__boundary__io_8fpp_8f90.html" target="_self">m_boundary_io.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__boundary__io.html" title="Boundary condition restart I/O, capillary/IGR buffer population, and grid-variable buffers.">m_boundary_io</a> </td></tr>
<tr id="row_4_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__boundary__primitives_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__boundary__primitives_8fpp_8f90.html" target="_self">m_boundary_primitives.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__boundary__primitives.html" title="Per-cell noncharacteristic boundary condition primitives applied in the ghost cells.">m_boundary_primitives</a> </td></tr>
<tr id="row_5_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__check__ib__patches_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__check__ib__patches_8fpp_8f90.html" target="_self">m_check_ib_patches.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__check__ib__patches.html" title="Validates geometry parameters and constraints for immersed boundary patches.">m_check_ib_patches</a> </td></tr>
<tr id="row_6_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__check__patches_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__check__patches_8fpp_8f90.html" target="_self">m_check_patches.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__check__patches.html" title="Validates geometry parameters and constraints for initial condition patches.">m_check_patches</a> </td></tr>
<tr id="row_7_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__checker_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__checker_8fpp_8f90.html" target="_self">m_checker.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__checker.html" title="Checks pre-process input file parameters for compatibility and correctness.">m_checker</a> </td></tr>
<tr id="row_8_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__checker__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__checker__common_8fpp_8f90.html" target="_self">m_checker_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__checker__common.html" title="Shared input validation checks for grid dimensions and AMD GPU compiler limits.">m_checker_common</a> </td></tr>
<tr id="row_9_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__chemistry_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__chemistry_8fpp_8f90.html" target="_self">m_chemistry.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__chemistry.html" title="Multi-species chemistry interface for thermodynamic properties, reaction rates, and transport coeffic...">m_chemistry</a> </td></tr>
<tr id="row_10_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__constants_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__constants_8fpp_8f90.html" target="_self">m_constants.fpp.f90</a></td><td class="desc">Contains constant values used throughout the code(s) </td></tr>
<tr id="row_11_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__data__output_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__data__output_8fpp_8f90.html" target="_self">m_data_output.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__data__output.html" title="Writes grid and initial condition data to serial or parallel output files.">m_data_output</a> </td></tr>
<tr id="row_12_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__derived__types_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__derived__types_8fpp_8f90.html" target="_self">m_derived_types.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__derived__types.html" title="Shared derived types for field data, patch geometry, bubble dynamics, and MPI I/O structures.">m_derived_types</a> </td></tr>
<tr id="row_13_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__finite__differences_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__finite__differences_8fpp_8f90.html" target="_self">m_finite_differences.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__finite__differences.html" title="Finite difference operators for computing divergence of velocity fields.">m_finite_differences</a> </td></tr>
<tr id="row_14_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__global__parameters_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__global__parameters_8fpp_8f90.html" target="_self">m_global_parameters.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__global__parameters.html" title="Defines global parameters for the computational domain, simulation algorithm, and initial conditions.">m_global_parameters</a> </td></tr>
<tr id="row_15_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__global__parameters__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__global__parameters__common_8fpp_8f90.html" target="_self">m_global_parameters_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__global__parameters__common.html" title="Shared global parameters and equation-index setup for all three executables. Each per-target m_global...">m_global_parameters_common</a> </td></tr>
<tr id="row_16_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__helper_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__helper_8fpp_8f90.html" target="_self">m_helper.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__helper.html" title="Utility routines for bubble model setup, coordinate transforms, array sampling, and special functions...">m_helper</a> </td></tr>
<tr id="row_17_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__helper__basic_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__helper__basic_8fpp_8f90.html" target="_self">m_helper_basic.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__helper__basic.html" title="Basic floating-point utilities: approximate equality, default detection, and coordinate bounds.">m_helper_basic</a> </td></tr>
<tr id="row_18_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__icpp__patches_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__icpp__patches_8fpp_8f90.html" target="_self">m_icpp_patches.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__icpp__patches.html" title="Allocate memory and read initial condition data for IC extrusion.">m_icpp_patches</a> </td></tr>
<tr id="row_19_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__initial__condition_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__initial__condition_8fpp_8f90.html" target="_self">m_initial_condition.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__initial__condition.html" title="Assembles initial conditions by layering prioritized patches via constructive solid geometry.">m_initial_condition</a> </td></tr>
<tr id="row_20_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__model_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__model_8fpp_8f90.html" target="_self">m_model.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__model.html" title="Binary STL file reader and processor for immersed boundary geometry.">m_model</a> </td></tr>
<tr id="row_21_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__mpi__common_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__mpi__common_8fpp_8f90.html" target="_self">m_mpi_common.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__mpi__common.html" title="MPI communication layer: domain decomposition, halo exchange, reductions, and parallel I/O setup.">m_mpi_common</a> </td></tr>
<tr id="row_22_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__mpi__proxy_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__mpi__proxy_8fpp_8f90.html" target="_self">m_mpi_proxy.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__mpi__proxy.html" title="Broadcasts user inputs and decomposes the domain across MPI ranks for pre-processing.">m_mpi_proxy</a> </td></tr>
<tr id="row_23_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__patch__geometries_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__patch__geometries_8fpp_8f90.html" target="_self">m_patch_geometries.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__patch__geometries.html" title="Contains helper functions specific to various patch gemoetries for determining if a grid cell lies in...">m_patch_geometries</a> </td></tr>
<tr id="row_24_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__perturbation_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__perturbation_8fpp_8f90.html" target="_self">m_perturbation.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__perturbation.html" title="Perturbs initial mean flow fields with random noise, mixing-layer instabilities, or simplex noise.">m_perturbation</a> </td></tr>
<tr id="row_25_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__phase__change_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__phase__change_8fpp_8f90.html" target="_self">m_phase_change.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__phase__change.html" title="Phase transition relaxation solvers for liquid-vapor flows with cavitation and boiling.">m_phase_change</a> </td></tr>
<tr id="row_26_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__simplex__noise_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__simplex__noise_8fpp_8f90.html" target="_self">m_simplex_noise.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__simplex__noise.html" title="2D and 3D simplex noise generation for procedural initial condition perturbations">m_simplex_noise</a> </td></tr>
<tr id="row_27_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__start__up_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__start__up_8fpp_8f90.html" target="_self">m_start_up.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__start__up.html" title="Reads and validates user inputs, loads existing grid/IC data, and initializes pre-process modules.">m_start_up</a> </td></tr>
<tr id="row_28_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__variables__conversion_8fpp_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__variables__conversion_8fpp_8f90.html" target="_self">m_variables_conversion.fpp.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__variables__conversion.html" title="Conservative-to-primitive variable conversion, mixture property evaluation, and pressure computation.">m_variables_conversion</a> </td></tr>
<tr id="row_29_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__compile__specific_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__compile__specific_8f90.html" target="_self">m_compile_specific.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__compile__specific.html" title="Platform-specific file and directory operations: create, delete, inquire, getcwd, and basename.">m_compile_specific</a> </td></tr>
<tr id="row_30_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__delay__file__access_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__delay__file__access_8f90.html" target="_self">m_delay_file_access.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__delay__file__access.html" title="Rank-staggered file access delays to prevent I/O contention on parallel file systems.">m_delay_file_access</a> </td></tr>
<tr id="row_31_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__nvtx_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__nvtx_8f90.html" target="_self">m_nvtx.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__nvtx.html" title="NVIDIA NVTX profiling API bindings for GPU performance instrumentation.">m_nvtx</a> </td></tr>
<tr id="row_32_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__precision__select_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__precision__select_8f90.html" target="_self">m_precision_select.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__precision__select.html" title="Working-precision kind selection (half/single/double) and corresponding MPI datatype parameters.">m_precision_select</a> </td></tr>
<tr id="row_33_" class="odd"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="m__grid_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="m__grid_8f90.html" target="_self">m_grid.f90</a></td><td class="desc">Contains module <a class="el" href="namespacem__grid.html" title="Generates uniform or stretched rectilinear grids with hyperbolic-tangent spacing.">m_grid</a> </td></tr>
<tr id="row_34_" class="even"><td class="entry"><span style="width:16px;display:inline-block;"> </span><a href="p__main_8f90_source.html"><span class="icondoc"><div class="doc-icon"></div></span></a><a class="el" href="p__main_8f90.html" target="_self">p_main.f90</a></td><td class="desc">Contains program p_main </td></tr>
</table>
</div><!-- directory -->
</div><!-- contents -->
</div><!-- doc-content -->
</div><!-- container -->
<!-- HTML footer for doxygen 1.9.1-->
<!-- start footer part -->
<div id="nav-path" class="navpath">
<ul></ul>
</div>
</body>
</html>